@@ -117,8 +117,8 @@ sub funcname_to_id {
 
     $self->{_func_cache}->{$db}->{funcname2id}->{$funcname} or do {
         my $func = $self->driver_for($db)->func_from_name($funcname);
-        $self->{_func_cache}->{$db}->{funcname2id}->{$funcname} = $func->id;
-        $self->{_func_cache}->{$db}->{funcid2name}->{$func->id} = $func->name;
+        $self->{_func_cache}->{$db}->{funcname2id}->{$funcname} = $func->{id};
+        $self->{_func_cache}->{$db}->{funcid2name}->{$func->{id}} = $func->{name};
 
     };
     $self->{_func_cache}->{$db}->{funcname2id}->{$funcname};
@@ -138,8 +138,8 @@ sub funcid_to_name {
 
     $self->{_func_cache}->{$db}->{funcid2name}->{$funcid} or do {
         my $func = $self->driver_for($db)->func_from_id($funcid);
-        $self->{_func_cache}->{$db}->{funcname2id}->{$func->name} = $func->id;
-        $self->{_func_cache}->{$db}->{funcidename}->{$funcid} = $func->name;
+        $self->{_func_cache}->{$db}->{funcname2id}->{$func->name} = $func->{id};
+        $self->{_func_cache}->{$db}->{funcidename}->{$funcid} = $func->{name};
     };
     $self->{_func_cache}->{$db}->{funcid2name}->{$funcid};
 }
