@@ -256,7 +256,8 @@ mysql:
         run_after       INTEGER UNSIGNED NOT NULL DEFAULT 0,
         retry_cnt       INTEGER UNSIGNED NOT NULL DEFAULT 0,
         priority        INTEGER UNSIGNED NOT NULL DEFAULT 0,
-        UNIQUE(func_id, uniqkey)
+        UNIQUE(func_id, uniqkey),
+        KEY priority (priority)
     )
   - |-
     CREATE TABLE exception_log (
